@@ -180,3 +180,7 @@ STACK_SPOKE_PREP_STACK_NAME = f"{BOOTSTRAP_STACK_NAME}-stack-execution"
 
 
 USE_SERVICE_ROLE_DEFAULT = False
+
+
+MANIFEST_STATUS_FIELD_NAME = "status"
+MANIFEST_STATUS_FIELD_VALUE_IGNORED = "ignored"
